@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 3379 2007-12-14 21:14:42Z richb $"
-__version__   = "$Revision: 3379 $"
-__date__      = "$Date: 2007-12-14 16:14:42 -0500 (Fri, 14 Dec 2007) $"
+__id__        = "$Id: braillegenerator.py 3638 2008-02-25 21:50:59Z joanied $"
+__version__   = "$Revision: 3638 $"
+__date__      = "$Date: 2008-02-25 16:50:59 -0500 (Mon, 25 Feb 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -331,9 +331,6 @@ class BrailleGenerator:
 
         text = ""
         state = obj.getState()
-        text = self._script.appendString(
-            text,
-            settings.brailleCheckBoxIndicators[indicatorindex])
 
         text = self._script.appendString(
             text, self._script.getDisplayedLabel(obj))
@@ -344,7 +341,9 @@ class BrailleGenerator:
             text, self._getTextForRole(obj, pyatspi.ROLE_CHECK_BOX))
 
         regions = []
-        componentRegion = braille.Component(obj, text)
+        componentRegion = braille.Component(
+            obj, text,
+            indicator=settings.brailleCheckBoxIndicators[indicatorindex])
         regions.append(componentRegion)
 
         return [regions, componentRegion]
@@ -372,9 +371,6 @@ class BrailleGenerator:
 
         text = ""
         state = obj.getState()
-        text = self._script.appendString(
-            text,
-            settings.brailleCheckBoxIndicators[indicatorindex])
 
         text = self._script.appendString(
             text, self._script.getDisplayedLabel(obj))
@@ -390,7 +386,9 @@ class BrailleGenerator:
                                       "")
 
         regions = []
-        componentRegion = braille.Component(obj, text)
+        componentRegion = braille.Component(
+            obj, text,
+            indicator=settings.brailleCheckBoxIndicators[indicatorindex])
         regions.append(componentRegion)
 
         return [regions, componentRegion]
@@ -764,9 +762,9 @@ class BrailleGenerator:
         #
         state = obj.getState()
         if state.contains(pyatspi.STATE_CHECKED):
-            text = self._script.appendString(
-                text,
-                settings.brailleCheckBoxIndicators[1])
+            indicator = settings.brailleCheckBoxIndicators[1]
+        else:
+            indicator = ''
 
         text = self._script.appendString(
             text, self._script.getDisplayedLabel(obj))
@@ -781,7 +779,7 @@ class BrailleGenerator:
                                       "")
 
         regions = []
-        componentRegion = braille.Component(obj, text)
+        componentRegion = braille.Component(obj, text, indicator=indicator)
         regions.append(componentRegion)
 
         return [regions, componentRegion]
@@ -968,10 +966,6 @@ class BrailleGenerator:
 
         text = ""
         state = obj.getState()
-        text = self._script.appendString(
-            settings.brailleRadioButtonIndicators[
-                int(state.contains(pyatspi.STATE_CHECKED))],
-            text)
 
         text = self._script.appendString(
             text, self._script.getDisplayedLabel(obj))
@@ -988,7 +982,10 @@ class BrailleGenerator:
         text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
-        componentRegion = braille.Component(obj, text)
+        componentRegion = braille.Component(
+            obj, text,
+            indicator=settings.brailleRadioButtonIndicators[ \
+            int(state.contains(pyatspi.STATE_CHECKED))])
         regions.append(componentRegion)
 
         return [regions, componentRegion]
@@ -1009,10 +1006,6 @@ class BrailleGenerator:
         text = ""
 
         state = obj.getState()
-        text = self._script.appendString(
-            settings.brailleRadioButtonIndicators[
-                state.contains(pyatspi.STATE_CHECKED)],
-            text)
 
         text = self._script.appendString(
             text, self._script.getDisplayedLabel(obj))
@@ -1028,7 +1021,10 @@ class BrailleGenerator:
                                       "")
 
         regions = []
-        componentRegion = braille.Component(obj, text)
+        componentRegion = braille.Component(
+            obj, text,
+            indicator=settings.brailleRadioButtonIndicators[ \
+            int(state.contains(pyatspi.STATE_CHECKED))])
         regions.append(componentRegion)
 
         return [regions, componentRegion]
@@ -1189,6 +1185,8 @@ class BrailleGenerator:
                 regions = [regions, cellFocusedRegion]
                 return regions
 
+        label = None
+
         # [[[TODO: WDW - Attempt to infer the cell type.  There's a
         # bunch of stuff we can do here, such as check the EXPANDABLE
         # state, check the NODE_CHILD_OF relation, etc.  Logged as
@@ -1218,17 +1216,20 @@ class BrailleGenerator:
                         n = table.getColumnAtIndex(obj.getIndexInParent())
                         accHeader = table.getColumnHeader(n)
                         regions[0].append(braille.Region(" "))
-                        regions[0].append(braille.Region(accHeader.name))
+                        label = accHeader.name
+                        regions[0].append(braille.Region(label))
 
                     break
 
+        descendant = self._script.getRealActiveDescendant(obj)
         if len(regions) == 0:
-            regions = self._getDefaultBrailleRegions(
-                              self._script.getRealActiveDescendant(obj))
+            regions = self._getDefaultBrailleRegions(descendant)
         else:
-            [cellRegions, focusRegion] = self._getDefaultBrailleRegions(\
-                self._script.getRealActiveDescendant(obj))
-            regions[0].extend(cellRegions)
+            cellText = self._script.getDisplayedText(descendant)
+            if not cellText or (cellText and label != cellText):
+                [cellRegions, focusRegion] = \
+                    self._getDefaultBrailleRegions(descendant)
+                regions[0].extend(cellRegions)
 
         # Check to see if this table cell contains an icon (image).
         # If yes:
@@ -1319,6 +1320,12 @@ class BrailleGenerator:
                 focusRowRegion = None
                 for i in range(0, table.nColumns):
                     cell = table.getAccessibleAt(row, i)
+                    if not cell:
+                        debug.println(debug.LEVEL_WARNING,
+                             "ERROR: braillegenerator." \
+                             + "_getBrailleRegionsForTableCellRow" \
+                             + " no accessible at (%d, %d)" % (row, i))
+                        continue
                     state = cell.getState()
                     showing = state.contains(pyatspi.STATE_SHOWING)
                     if showing:
@@ -1403,23 +1410,9 @@ class BrailleGenerator:
 
         self._debugGenerator("_getBrailleRegionsForTerminal", obj)
 
-        title = None
-        frame = self._script.getFrame(obj)
-        if frame:
-            title = frame.name
-        if not title:
-            title = self._script.getDisplayedLabel(obj)
-
-        text = title
-        text = self._script.appendString(
-            text, rolenames.getBrailleForRoleName(obj))
-
         regions = []
-        regions.append(braille.Region(text))
-
         textRegion = braille.Text(obj)
         regions.append(textRegion)
-
         return [regions, textRegion]
 
     def _getBrailleRegionsForToggleButton(self, obj):
