@@ -19,9 +19,9 @@
 
 """Provides the default implementation for flat review for Orca."""
 
-__id__        = "$Id: flat_review.py 3560 2008-02-11 17:35:26Z wwalker $"
-__version__   = "$Revision: 3560 $"
-__date__      = "$Date: 2008-02-11 12:35:26 -0500 (Mon, 11 Feb 2008) $"
+__id__        = "$Id: flat_review.py 3598 2008-02-19 00:48:06Z joanied $"
+__version__   = "$Revision: 3598 $"
+__date__      = "$Date: 2008-02-18 19:48:06 -0500 (Mon, 18 Feb 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1305,7 +1305,11 @@ class Context:
             return []
 
         zones = []
-        rootexts = root.queryComponent().getExtents(0)
+        try:
+            rootexts = root.queryComponent().getExtents(0)
+        except:
+            return []
+
         rootrole = root.getRole()
 
         # If we're at a leaf node, then we've got a good one on our hands.
@@ -1655,8 +1659,6 @@ class Context:
                             len(zone.words[wordIndex].string.decode("UTF-8"))
                 regionWithFocus.cursorOffset += self.charIndex
                 regionWithFocus.repositionCursor()
-                if isinstance(regionWithFocus, braille.ReviewComponent):
-                    regionWithFocus.expandRegion()
                 break
 
         return [regions, regionWithFocus]
