@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: Evolution.py 3457 2008-01-14 20:01:29Z richb $"
-__version__   = "$Revision: 3457 $"
-__date__      = "$Date: 2008-01-14 15:01:29 -0500 (Mon, 14 Jan 2008) $"
+__id__        = "$Id: Evolution.py 3508 2008-01-28 15:38:41Z wwalker $"
+__version__   = "$Revision: 3508 $"
+__date__      = "$Date: 2008-01-28 10:38:41 -0500 (Mon, 28 Jan 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -36,6 +36,7 @@ import orca.braille as braille
 import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.speech as speech
+import orca.speechgenerator as speechgenerator
 import orca.speechserver as speechserver
 import orca.settings as settings
 import orca.chnames as chnames
@@ -232,6 +233,45 @@ class WhereAmI(where_am_I.WhereAmI):
 
         return [textContents, startOffset, endOffset]
 
+class SpeechGenerator(speechgenerator.SpeechGenerator):
+    """Overrides _getSpeechForTableCell so that, if this is an expanded 
+       table cell,  we can strip off the "0 items".
+    """
+
+    def __init__(self, script):
+        speechgenerator.SpeechGenerator.__init__(self, script)
+
+    def _getSpeechForTableCell(self, obj, already_focused):
+        """Get the speech utterances for a single table cell
+
+        Arguments:
+        - obj: the table
+        - already_focused: False if object just received focus
+
+        Returns a list of utterances to be spoken for the object.
+        """
+
+        utterances = speechgenerator.SpeechGenerator.\
+                      _getSpeechForTableCell(self, obj, already_focused)
+
+        # Check that we are in a table cell in the mail message header list.
+        # If we are and this table cell has an expanded state, and the first
+        # token of the last utterances is "0", then strip off that last 
+        # utterance ("0 items"). See bug #432308 for more details.
+        #
+        rolesList = [pyatspi.ROLE_TABLE_CELL, \
+                     pyatspi.ROLE_TREE_TABLE, \
+                     pyatspi.ROLE_UNKNOWN]
+        if self._script.isDesiredFocusedItem(obj, rolesList):
+            state = obj.getState()
+            if state and state.contains(pyatspi.STATE_EXPANDABLE):
+                if state.contains(pyatspi.STATE_EXPANDED):
+                    tokens = utterances[-1].split()
+                    if tokens[0] == "0":
+                        utterances = utterances[0:-1]
+
+        return utterances
+
 ########################################################################
 #                                                                      #
 # The Evolution script class.                                          #
@@ -319,6 +359,12 @@ class Script(default.Script):
             #
             _("calendar event"))
 
+    def getSpeechGenerator(self):
+        """Returns the speech generator for this script.
+        """
+
+        return SpeechGenerator(self)
+
     def getWhereAmI(self):
         """Returns the "where am I" class for this script.
         """
@@ -908,6 +954,16 @@ class Script(default.Script):
             column = \
                 parentTable.getColumnAtIndex(event.source.getIndexInParent())
 
+            # If we are on the same row, then just speak/braille the table
+            # cell as if settings.readTableCellRow was False. 
+            # See bug #503874 for more details.
+            #
+            if self.lastMessageRow == row:
+                default.Script.locusOfFocusChanged(self, event,
+                                           oldLocusOfFocus, newLocusOfFocus)
+                settings.readTableCellRow = True
+                return
+
             # This is an indication of whether we should speak all the table
             # cells (the user has moved focus up or down the list, or just
             # deleted a message), or just the current one (focus has moved
@@ -971,6 +1027,12 @@ class Script(default.Script):
 
                     checkbox = False
                     toRead = True
+                    # Whether or not we want to replace the cell's column
+                    # header with a more user-friendly alternative name.
+                    # Currently we only do this with the "status" column,
+                    # which we replace with "unread" if it is not checked.
+                    #
+                    useAlternativeName = False
                     try:
                         action = cell.queryAction()
                     except NotImplementedError:
@@ -990,6 +1052,15 @@ class Script(default.Script):
                                     #
                                     if header.name == _("Status"):
                                         toRead = not checked
+                                        useAlternativeName = True
+                                        break
+                                    # Translators: this is the name of the
+                                    # flagged column header in the message
+                                    # list in Evolution.  The name needs to
+                                    # match what Evolution is using.
+                                    #
+                                    elif header.name == _("Flagged"):
+                                        toRead = checked
                                         break
                                     if not checked:
                                         toRead = False
@@ -999,7 +1070,8 @@ class Script(default.Script):
                         # Speak/braille the column header for this table cell
                         # if it has focus (unless it's a checkbox).
                         #
-                        if not checkbox and verbose:
+                        if (verbose or (checkbox and column == i)) \
+                           and not useAlternativeName:
                             settings.brailleVerbosityLevel = \
                                 settings.VERBOSITY_LEVEL_BRIEF
                             settings.speechVerbosityLevel = \
@@ -1057,8 +1129,20 @@ class Script(default.Script):
                         elif header.name == _("Attachment"):
                             text = header.name
                             utterances = [ text ]
-                            brailleRegions.append(braille.Region(text))
-                            brailleRegions.append(braille.Region(" "))
+                            if column != i:
+                                brailleRegions.append(braille.Region(text))
+                                brailleRegions.append(braille.Region(" "))
+                        # Translators: this is the name of the
+                        # flagged column header in the message
+                        # list in Evolution.  The name needs to
+                        # match what Evolution is using.
+                        #
+                        elif header.name == _("Flagged"):
+                            text = header.name
+                            utterances = [ text ]
+                            if column != i:
+                                brailleRegions.append(braille.Region(text))
+                                brailleRegions.append(braille.Region(" "))
                         else:
                             brailleRegions.extend(cellRegions)
                             brailleRegions.append(braille.Region(" "))
