@@ -27,9 +27,9 @@ The following script specific key sequences are supported:
   Insert-[1-9]  -  Speak and braille a previous chat room message.
 """
 
-__id__        = "$Id: gaim.py 3435 2008-01-08 21:08:52Z richb $"
-__version__   = "$Revision: 3435 $"
-__date__      = "$Date: 2008-01-08 16:08:52 -0500 (Tue, 08 Jan 2008) $"
+__id__        = "$Id: gaim.py 3808 2008-04-04 23:01:33Z richb $"
+__version__   = "$Revision: 3808 $"
+__date__      = "$Date: 2008-04-04 19:01:33 -0400 (Fri, 04 Apr 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -55,6 +55,10 @@ from orca.orca_i18n import ngettext  # for ngettext support
 #
 prefixChatMessage = False
 
+# Whether we announce when a buddy is typing.
+#
+announceBuddyTyping = False
+
 # Possible ways of how Orca should speak pidgin chat messages.
 #
 SPEAK_ALL_MESSAGES              = 0
@@ -352,6 +356,10 @@ class Script(default.Script):
         #
         self.speakNameCheckButton = None
 
+        # Keep track of the last status message to see if it's changed.
+        #
+        self.lastStatus = None
+
         # To make pylint happy.
         #
         self.focusedChannelRadioButton = None
@@ -614,9 +622,9 @@ class Script(default.Script):
         if message and message != "":
             text += message
 
-        if text != "":
-            braille.displayMessage(text)
+        if len(text.strip()):
             speech.speak(text)
+        braille.displayMessage(text)
 
     def readPreviousMessage(self, inputEvent):
         """ Speak/braille a previous chat room message. Up to nine
@@ -696,6 +704,53 @@ class Script(default.Script):
                         line = _("New chat tab %s") % child.name
                         speech.speak(line)
 
+    def attribsToDictionary(self, dict_string):
+        """Creates a Python dict from a typical attributes list returned from
+        different AT-SPI methods.
+
+
+        Arguments:
+        - dict_string: A list of colon seperated key/value pairs seperated by
+        semicolons.
+        Returns a Python dict of the given attributes.
+        """
+        try:
+            return dict(
+                map(lambda pair: pair.strip().split(':'),
+                    dict_string.strip(';').split(';')))
+        except ValueError:
+            return {}
+
+    def getTextAttributes(self, acc, offset, get_defaults=False):
+        """Get the text attributes run for a given offset in a given accessible
+
+        Arguments:
+        - acc: An accessible.
+        - offset: Offset in the accessible's text for which to retrieve the
+        attributes.
+        - get_defaults: Get the default attributes as well as the unique ones.
+        Default is True
+
+        Returns a dictionary of attributes, a start offset where the attributes
+        begin, and an end offset. Returns ({}, 0, 0) if the accessible does not
+        support the text attribute.
+        """
+
+        rv = {}
+        try:
+            texti = acc.queryText()
+        except:
+            return rv, 0, 0
+
+        if get_defaults:
+            rv.update(self.attribsToDictionary(texti.getDefaultAttributes()))
+
+        attrib_str, start, end = texti.getAttributes(offset)
+
+        rv.update(self.attribsToDictionary(attrib_str))
+
+        return rv, start, end
+
     def onTextInserted(self, event):
         """Called whenever text is inserted into one of Gaim's text
         objects.  If the object is an instant message or chat, speak
@@ -759,6 +814,21 @@ class Script(default.Script):
 
             chatRoomName = self.getDisplayedText(chatRoomTab)
 
+            # If the user doesn't want announcements for when their buddies
+            # are typing (or have stopped typing), and this is such a message,
+            # then just return. The only reliable way to identify such text
+            # is by the scale.  We also want to store the last message because
+            # msn seems to be sending a constant stream of "is typing" updates.
+            #
+            attr, start, end = \
+                self.getTextAttributes(event.source, event.detail1)
+            if float(attr.get('scale', '1')) < 1:
+                if not announceBuddyTyping or self.lastStatus == message:
+                    return
+                self.lastStatus = message
+            else:
+                self.lastStatus = None
+
             # If the new message came from the room with focus, we don't
             # want to speak its name even if prefixChatMessage is enabled.
             #
@@ -770,9 +840,11 @@ class Script(default.Script):
 
             # Add the latest message to the list of saved ones. For each
             # one added, the oldest one automatically gets dropped off.
+            # We don't want to do this for the status messages however.
             #
-            self.previousMessages.append(message)
-            self.previousChatRoomNames.append(chatRoomName)
+            if not self.lastStatus:
+                self.previousMessages.append(message)
+                self.previousChatRoomNames.append(chatRoomName)
 
         elif isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent) \
              and orca_state.lastNonModifierKeyEvent \
