@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 3495 2008-01-24 16:53:04Z shaeger $"
-__version__   = "$Revision: 3495 $"
-__date__      = "$Date: 2008-01-24 11:53:04 -0500 (Thu, 24 Jan 2008) $"
+__id__        = "$Id: settings.py 3661 2008-02-29 18:18:36Z shaeger $"
+__version__   = "$Revision: 3661 $"
+__date__      = "$Date: 2008-02-29 13:18:36 -0500 (Fri, 29 Feb 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -155,7 +155,9 @@ userCustomizableSettings = [
     "enabledBrailledTextAttributes",
     "textAttributesBrailleIndicator",
     "enableProgressBarUpdates",
-    "progressBarUpdateInterval"
+    "progressBarUpdateInterval",
+    "enableContractedBraille",
+    "brailleContractionTable"
 ]
 
 # The name of the module that hold the user interface for the main window
@@ -905,3 +907,15 @@ ignoredEventsList = ['object:bounds-changed']
 # changes.  
 #
 inferLiveRegions = True
+
+# Contracted braille support.
+# 
+enableContractedBraille = False
+
+# Contracted braille table.
+# 
+brailleContractionTable = ''
+
+# Use Collection Interface?
+# 
+useCollection = True
